@@ -5,7 +5,8 @@ use Carp;
 use WWW::Mechanize;
 use WWW::Mechanize::FormFiller;
 use HTTP::Cookies;
-use base qw( Term::Shell Exporter );
+use parent qw( Term::Shell );
+use Exporter 'import';
 use FindBin;
 use File::Temp qw(tempfile);
 use URI::URL;
@@ -15,7 +16,7 @@ use HTML::TokeParser::Simple;
 use B::Deparse;
 
 use vars qw( $VERSION @EXPORT %munge_map );
-$VERSION = '0.50';
+$VERSION = '0.52';
 @EXPORT = qw( &shell );
 
 =head1 NAME
